@@ -9,8 +9,11 @@ from sklearn.linear_model import RidgeClassifierCV
 from convst.transformers._input_transformers import c_StandardScaler
 from convst.transformers import R_DST
 
+from convst.utils.checks_utils import check_n_jobs
 from sklearn.metrics import accuracy_score
 
+from numba import set_num_threads
+
 class R_DST_Ridge(BaseEstimator, ClassifierMixin):
     """
     A wrapper class which use R_DST as a transformer, followed by a Ridge 
@@ -67,6 +70,9 @@ class R_DST_Ridge(BaseEstimator, ClassifierMixin):
         n_samples=None,
         n_shapelets=10_000,
         shapelet_lengths=[11],
+        shapelet_lengths_bounds=None,
+        lengths_bounds_reduction=0.5,
+        prime_dilations=False,
         proba_norm=0.8,
         percentiles=[5,10],
         n_jobs=1,
@@ -81,18 +87,25 @@ class R_DST_Ridge(BaseEstimator, ClassifierMixin):
         self.fit_intercept=fit_intercept
         self.transform_type=transform_type
         self.phase_invariance=phase_invariance
+        self.prime_dilations=prime_dilations
         self.distance=distance
         self.alpha=alpha
         self.normalize_output=normalize_output
         self.n_samples=n_samples
+        self.shapelet_lengths_bounds=shapelet_lengths_bounds
+        self.lengths_bounds_reduction=lengths_bounds_reduction
         self.n_shapelets=n_shapelets
         self.shapelet_lengths=shapelet_lengths
         self.proba_norm=proba_norm
         self.percentiles=percentiles
-        self.n_jobs=n_jobs
+        if isinstance(n_jobs, bool):
+            self.n_jobs=n_jobs
+        else:
+            self.n_jobs=check_n_jobs(n_jobs)
+            set_num_threads(self.n_jobs)
         self.random_state=random_state
         self.min_len=min_len
-
+    
     def _more_tags(self):
         return {
             "capability:variable_length": True,
@@ -114,13 +127,16 @@ class R_DST_Ridge(BaseEstimator, ClassifierMixin):
             phase_invariance=self.phase_invariance,
             distance=self.distance,
             alpha=self.alpha,
+            prime_dilations=self.prime_dilations,
+            shapelet_lengths_bounds=self.shapelet_lengths_bounds,
+            lengths_bounds_reduction=self.lengths_bounds_reduction,
             normalize_output=self.normalize_output,
             n_samples=self.n_samples,
             n_shapelets=self.n_shapelets,
+            n_jobs=False,
             shapelet_lengths=self.shapelet_lengths,
             proba_norm=self.proba_norm,
             percentiles=self.percentiles,
-            n_jobs=self.n_jobs,
             random_state=self.random_state,
             min_len=self.min_len 
         )
