@@ -1,7 +1,10 @@
 """
 This module contains sklearn compatible transformers.
 """
-from .RDST import R_DST
+from .rdst import R_DST
+
+
 __author__ = 'Antoine Guillaume antoine.guillaume45@gmail.com'
 
-__all__ = ["R_DST"]
\ No newline at end of file
+__all__ = ["R_DST"]
+
