@@ -12,14 +12,14 @@ from numpy import (
 from convst.transformers._commons import (
     get_subsequence, compute_shapelet_dist_vector,
     apply_one_shapelet_one_sample_multivariate, _combinations_1d,
-    generate_strides_2D
+    generate_strides_2D, prime_up_to
 )
 
 from numba import njit, prange
 
 @njit(cache=True)
-def _init_random_shapelet_params(
-    n_shapelets, shapelet_sizes, n_timestamps, p_norm, max_channels
+def M_SL_init_random_shapelet_params(
+    n_shapelets, shapelet_sizes, n_timestamps, p_norm, max_channels, prime_scheme
 ):
     """
     Initialize the parameters of the shapelets.    
@@ -58,11 +58,17 @@ def _init_random_shapelet_params(
 
     # Dilations
     upper_bounds = log2(floor_divide(n_timestamps - 1, lengths - 1))
-    powers = zeros(n_shapelets)
-    for i in prange(n_shapelets):
-        powers[i] = uniform(0, upper_bounds[i])
-    dilations = floor(power(2, powers)).astype(int64)
-
+    if prime_scheme:
+        primes = prime_up_to(int64(2**upper_bounds.max()))
+        dilations = zeros(n_shapelets, dtype=int64)
+        for i in prange(n_shapelets):
+            dilations[i] = choice(primes[primes<=int64(2**upper_bounds[i])])
+    else:
+        powers = zeros(n_shapelets)
+        for i in prange(n_shapelets):
+            powers[i] = uniform(0, upper_bounds[i])
+        dilations = floor(power(2, powers)).astype(int64)
+    
     # Init threshold array
     threshold = zeros(n_shapelets)
 
@@ -87,7 +93,7 @@ def _init_random_shapelet_params(
 @njit(cache=True, parallel=True)
 def M_SL_generate_shapelet(
     X, y, n_shapelets, shapelet_sizes, r_seed, p_norm, p_min, p_max, alpha,
-    dist_func, use_phase, max_channels
+    dist_func, use_phase, max_channels, prime_scheme
 ):
     """
     Given a time series dataset and parameters of the method, generate the
@@ -141,8 +147,8 @@ def M_SL_generate_shapelet(
 
     #Initialize shapelets
     values, lengths, dilations, threshold, normalize, n_channels, channel_ids = \
-    _init_random_shapelet_params(
-        n_shapelets, shapelet_sizes, n_timestamps, p_norm, max_channels
+    M_SL_init_random_shapelet_params(
+        n_shapelets, shapelet_sizes, n_timestamps, p_norm, max_channels, prime_scheme
     )
     #Initialize self similarity mask
     unique_dil = unique(dilations)
