@@ -13,8 +13,8 @@ from sklearn.base import BaseEstimator, TransformerMixin
 from sklearn.utils.validation import check_is_fitted, check_random_state
 
 from convst.utils.checks_utils import (
-    check_array_3D, check_array_1D, check_n_jobs, check_is_numeric, 
-    check_is_boolean
+    check_array_3D, check_array_1D, check_is_numeric, 
+    check_is_boolean, check_n_jobs
 )
 from convst.transformers._commons import manhattan, euclidean, squared_euclidean
 
@@ -103,12 +103,15 @@ class R_DST(BaseEstimator, TransformerMixin):
         n_samples=None,
         n_shapelets=10_000,
         shapelet_lengths=[11],
+        shapelet_lengths_bounds=None,
+        lengths_bounds_reduction=0.5,
+        prime_dilations=False,
         proba_norm=0.8,
         percentiles=[5,10],
-        n_jobs=1,
         random_state=None,
         max_channels=None,
-        min_len=None 
+        min_len=None,
+        n_jobs=1
     ):
         self.transform_type = self._validate_transform_type(transform_type)
         self.phase_invariance = check_is_boolean(phase_invariance)
@@ -118,13 +121,51 @@ class R_DST(BaseEstimator, TransformerMixin):
         self.n_samples = check_is_numeric(n_samples) if n_samples is not None else n_samples
         self.n_shapelets = int(check_is_numeric(n_shapelets))
         self.shapelet_lengths = check_array_1D(shapelet_lengths)
+        if shapelet_lengths_bounds is None:
+            self.shapelet_lengths_bounds = None
+        elif len(shapelet_lengths_bounds)==2:
+            self.shapelet_lengths_bounds = shapelet_lengths_bounds
+        else:
+            raise ValueError('Shapelets lengths bounds should be a 1D array with 2 values')
+        self.lengths_bounds_reduction=check_is_numeric(lengths_bounds_reduction)
+        if self.lengths_bounds_reduction>=1:
+            raise ValueError('lengths_bounds_reduction parameter should be in range [0,1[')
+        self.prime_dilations = check_is_boolean(prime_dilations)
         self.proba_norm = check_is_numeric(proba_norm)
         self.percentiles = self._validate_percentiles(percentiles)
-        self.n_jobs = check_n_jobs(n_jobs)
         self.random_state = check_random_state(random_state)
+        if isinstance(n_jobs, bool):
+            self.n_jobs=n_jobs
+        else:
+            self.n_jobs=check_n_jobs(n_jobs)
+            set_num_threads(self.n_jobs)
         self.max_channels=max_channels
         self.min_len=min_len
     
+    def _set_lengths(self):
+        if self.shapelet_lengths_bounds is None:
+            if self.shapelet_lengths.dtype == float:
+                return np.floor(self.min_len*self.shapelet_lengths)
+            else:
+                return self.shapelet_lengths
+        else:
+            b0 = self.shapelet_lengths_bounds[0]
+            b1 = self.shapelet_lengths_bounds[1]
+            
+            if isinstance(b0, float):
+                b0 = int(b0*self.min_len)
+            min_l = max(5,b0)
+            if isinstance(b1, float):
+                b1 = int(b1*self.min_len)
+            max_l = max(6,max(b0+1,b1+1))
+            #6 to ensure range 5,6 -> 5
+            lengths = np.asarray(list(range(min_l, max_l)))
+            if lengths.shape[0]>3:
+                n_remove = int(lengths.shape[0]*self.lengths_bounds_reduction)
+                if n_remove > 0:
+                    step = lengths.shape[0]//n_remove
+                    lengths = lengths[::step]
+            return lengths
         
     def fit(self, X, y):
         """
@@ -141,7 +182,6 @@ class R_DST(BaseEstimator, TransformerMixin):
             Class of the input time series.
 
         """
-        set_num_threads(self.n_jobs)
         self._set_fit_transform(X)
         if self.transform_type in [STR_MULTIVARIATE_VARIABLE, STR_UNIVARIATE_VARIABLE]:
             X, X_len = self._format_uneven_timestamps(X)
@@ -168,8 +208,8 @@ class R_DST(BaseEstimator, TransformerMixin):
         if self.max_channels is None:
             self.max_channels = n_features
         
-        if self.shapelet_lengths.dtype == float:
-            self.shapelet_lengths = np.floor(self.min_len*self.shapelet_lengths)
+        
+        self.shapelet_lengths = self._set_lengths()
         
         shapelet_lengths, seed = self._check_params(self.min_len)
         # Generate the shapelets
@@ -178,27 +218,27 @@ class R_DST(BaseEstimator, TransformerMixin):
                 X, y, self.n_shapelets, shapelet_lengths, seed, self.proba_norm,
                 self.percentiles[0], self.percentiles[1], self.alpha,
                 self._get_distance_function(), self.phase_invariance,
-                self.min_len, X_len
+                self.min_len, X_len, self.prime_dilations
             )
         elif self.transform_type == STR_MULTIVARIATE_VARIABLE:
             self.shapelets_ = self.fitter(
                 X, y, self.n_shapelets, shapelet_lengths, seed, self.proba_norm,
                 self.percentiles[0], self.percentiles[1], self.alpha,
                 self._get_distance_function(), self.phase_invariance,
-                self.max_channels, self.min_len, X_len
+                self.max_channels, self.min_len, X_len, self.prime_dilations
             )
         elif self.transform_type == STR_MUTLIVARIATE:
             self.shapelets_ = self.fitter(
                 X, y, self.n_shapelets, shapelet_lengths, seed, self.proba_norm,
                 self.percentiles[0], self.percentiles[1], self.alpha, 
                 self._get_distance_function(), self.phase_invariance, 
-                self.max_channels
+                self.max_channels, self.prime_dilations
             )
         elif self.transform_type == STR_UNIVARIATE:
             self.shapelets_ = self.fitter(
                 X, y, self.n_shapelets, shapelet_lengths, seed, self.proba_norm,
                 self.percentiles[0], self.percentiles[1], self.alpha, 
-                self._get_distance_function(), self.phase_invariance
+                self._get_distance_function(), self.phase_invariance, self.prime_dilations
             )
         else:
             raise ValueError('Unknown value for transform type parameter')
@@ -448,7 +488,7 @@ class R_DST(BaseEstimator, TransformerMixin):
                 raise ValueError('Input data goint {} timestamps, at least 4 are requiered. Input format should be (n_samples, n_features, n_timestamps)'.format(n_timestamps))
             else:
                 warnings.warn("All the values in 'shapelet_lengths' must be lower than or equal to 'n_timestamps' (got {} > {}). Changed shapelet size to {}".format(shapelet_lengths.max(), n_timestamps, n_timestamps//2))
-                shapelet_lengths = np.array([n_timestamps//2])
+                shapelet_lengths = shapelet_lengths[shapelet_lengths > n_timestamps] = n_timestamps//2
 
 
         rng = check_random_state(self.random_state)
